@@ -168,26 +168,20 @@ def main():
 
     # Output directory options
     output_options.add_argument(
-        '--prefix', action='store', metavar='DIR',
-        help='Set general directory prefix to DIR',
-        envvar='RFM_PREFIX', configvar='systems/prefix'
+        '--dont-restage', action='store_false', dest='clean_stagedir',
+        help='Reuse the test stage directory',
+        envvar='RFM_CLEAN_STAGEDIR', configvar='general/clean_stagedir'
+    )
+    output_options.add_argument(
+        '--keep-stage-files', action='store_true',
+        help='Keep stage directories even for successful checks',
+        envvar='RFM_KEEP_STAGE_FILES', configvar='general/keep_stage_files'
     )
     output_options.add_argument(
         '-o', '--output', action='store', metavar='DIR',
         help='Set output directory prefix to DIR',
         envvar='RFM_OUTPUT_DIR', configvar='systems/outputdir'
     )
-    output_options.add_argument(
-        '-s', '--stage', action='store', metavar='DIR',
-        help='Set stage directory prefix to DIR',
-        envvar='RFM_STAGE_DIR', configvar='systems/stagedir'
-    )
-    output_options.add_argument(
-        '--timestamp', action='store', nargs='?', const='', metavar='TIMEFMT',
-        help=('Append a timestamp to the output and stage directory prefixes '
-              '(default: "%%FT%%T")'),
-        envvar='RFM_TIMESTAMP_DIRS', configvar='general/timestamp_dirs'
-    )
     output_options.add_argument(
         '--perflogdir', action='store', metavar='DIR',
         help=('Set performance log data directory prefix '
@@ -196,19 +190,9 @@ def main():
         configvar='logging/handlers_perflog/filelog_basedir'
     )
     output_options.add_argument(
-        '--keep-stage-files', action='store_true',
-        help='Keep stage directories even for successful checks',
-        envvar='RFM_KEEP_STAGE_FILES', configvar='general/keep_stage_files'
-    )
-    output_options.add_argument(
-        '--dont-restage', action='store_false', dest='clean_stagedir',
-        help='Reuse the test stage directory',
-        envvar='RFM_CLEAN_STAGEDIR', configvar='general/clean_stagedir'
-    )
-    output_options.add_argument(
-        '--save-log-files', action='store_true', default=False,
-        help='Save ReFrame log files to the output directory',
-        envvar='RFM_SAVE_LOG_FILES', configvar='general/save_log_files'
+        '--prefix', action='store', metavar='DIR',
+        help='Set general directory prefix to DIR',
+        envvar='RFM_PREFIX', configvar='systems/prefix'
     )
     output_options.add_argument(
         '--report-file', action='store', metavar='FILE',
@@ -222,6 +206,23 @@ def main():
         envvar='RFM_REPORT_JUNIT',
         configvar='general/report_junit'
     )
+    output_options.add_argument(
+        '-s', '--stage', action='store', metavar='DIR',
+        help='Set stage directory prefix to DIR',
+        envvar='RFM_STAGE_DIR', configvar='systems/stagedir'
+    )
+    output_options.add_argument(
+        '--save-log-files', action='store_true', default=False,
+        help='Save ReFrame log files to the output directory',
+        envvar='RFM_SAVE_LOG_FILES', configvar='general/save_log_files'
+    )
+    output_options.add_argument(
+        '--timestamp', action='store', nargs='?', const='%FT%T',
+        metavar='TIMEFMT',
+        help=('Append a timestamp to the output and stage directory prefixes '
+              '(default: "%%FT%%T")'),
+        envvar='RFM_TIMESTAMP_DIRS', configvar='general/timestamp_dirs'
+    )
 
     # Check discovery options
     locate_options.add_argument(
@@ -229,12 +230,6 @@ def main():
         help="Add PATH to the check search path list",
         envvar='RFM_CHECK_SEARCH_PATH :', configvar='general/check_search_path'
     )
-    locate_options.add_argument(
-        '-R', '--recursive', action='store_true',
-        help='Search for checks in the search path recursively',
-        envvar='RFM_CHECK_SEARCH_RECURSIVE',
-        configvar='general/check_search_recursive'
-    )
     locate_options.add_argument(
         '--ignore-check-conflicts', action='store_true',
         help=('Skip checks with conflicting names '
@@ -242,26 +237,17 @@ def main():
         envvar='RFM_IGNORE_CHECK_CONFLICTS',
         configvar='general/ignore_check_conflicts'
     )
+    locate_options.add_argument(
+        '-R', '--recursive', action='store_true',
+        help='Search for checks in the search path recursively',
+        envvar='RFM_CHECK_SEARCH_RECURSIVE',
+        configvar='general/check_search_recursive'
+    )
 
     # Select options
     select_options.add_argument(
-        '-t', '--tag', action='append', dest='tags', metavar='PATTERN',
-        default=[],
-        help='Select checks with at least one tag matching PATTERN'
-    )
-    select_options.add_argument(
-        '-n', '--name', action='append', dest='names', default=[],
-        metavar='PATTERN', help='Select checks whose name matches PATTERN'
-    )
-    select_options.add_argument(
-        '-x', '--exclude', action='append', dest='exclude_names',
-        metavar='PATTERN', default=[],
-        help='Exclude checks whose name matches PATTERN'
-    )
-    select_options.add_argument(
-        '-p', '--prgenv', action='append', default=[r'.*'],  metavar='PATTERN',
-        help=('Select checks with at least one '
-              'programming environment matching PATTERN')
+        '--cpu-only', action='store_true',
+        help='Select only CPU checks'
     )
     select_options.add_argument(
         '--failed', action='store_true',
@@ -272,19 +258,39 @@ def main():
         help='Select only GPU checks'
     )
     select_options.add_argument(
-        '--cpu-only', action='store_true',
-        help='Select only CPU checks'
+        '-n', '--name', action='append', dest='names', default=[],
+        metavar='PATTERN', help='Select checks whose name matches PATTERN'
+    )
+    select_options.add_argument(
+        '-p', '--prgenv', action='append', default=[r'.*'],  metavar='PATTERN',
+        help=('Select checks with at least one '
+              'programming environment matching PATTERN')
+    )
+    select_options.add_argument(
+        '-t', '--tag', action='append', dest='tags', metavar='PATTERN',
+        default=[],
+        help='Select checks with at least one tag matching PATTERN'
+    )
+    select_options.add_argument(
+        '-x', '--exclude', action='append', dest='exclude_names',
+        metavar='PATTERN', default=[],
+        help='Exclude checks whose name matches PATTERN'
     )
 
     # Action options
     action_options.add_argument(
-        '-l', '--list', action='store_true',
-        help='List the selected checks'
+        '--ci-generate', action='store', metavar='FILE',
+        help=('Generate into FILE a Gitlab CI pipeline '
+              'for the selected tests and exit'),
     )
     action_options.add_argument(
         '-L', '--list-detailed', action='store_true',
         help='List the selected checks providing details for each test'
     )
+    action_options.add_argument(
+        '-l', '--list', action='store_true',
+        help='List the selected checks'
+    )
     action_options.add_argument(
         '--list-tags', action='store_true',
         help='List the unique tags found in the selected tests and exit'
@@ -293,47 +299,11 @@ def main():
         '-r', '--run', action='store_true',
         help='Run the selected checks'
     )
-    action_options.add_argument(
-        '--ci-generate', action='store', metavar='FILE',
-        help=('Generate into FILE a Gitlab CI pipeline '
-              'for the selected tests and exit'),
-    )
 
     # Run options
     run_options.add_argument(
-        '-J', '--job-option', action='append', metavar='OPT',
-        dest='job_options', default=[],
-        help='Pass option OPT to job scheduler'
-    )
-    run_options.add_argument(
-        '--force-local', action='store_true',
-        help='Force local execution of checks'
-    )
-    run_options.add_argument(
-        '--skip-sanity-check', action='store_true',
-        help='Skip sanity checking'
-    )
-    run_options.add_argument(
-        '--skip-performance-check', action='store_true',
-        help='Skip performance checking'
-    )
-    run_options.add_argument(
-        '--strict', action='store_true',
-        help='Enforce strict performance checking'
-    )
-    run_options.add_argument(
-        '--skip-system-check', action='store_true',
-        help='Skip system check'
-    )
-    run_options.add_argument(
-        '--skip-prgenv-check', action='store_true',
-        help='Skip programming environment check'
-    )
-    run_options.add_argument(
-        '-S', '--setvar', action='append', metavar='[TEST.]VAR=VAL',
-        dest='vars', default=[],
-        help=('Set test variable VAR to VAL in all tests '
-              'or optionally in TEST only')
+        '--disable-hook', action='append', metavar='NAME', dest='hooks',
+        default=[], help='Disable a pipeline hook for this run'
     )
     run_options.add_argument(
         '--exec-policy', metavar='POLICY', action='store',
@@ -341,7 +311,18 @@ def main():
         help='Set the execution policy of ReFrame (default: "async")'
     )
     run_options.add_argument(
-        '--mode', action='store', help='Execution mode to use'
+        '--flex-alloc-nodes', action='store',
+        dest='flex_alloc_nodes', metavar='{all|STATE|NUM}', default=None,
+        help='Set strategy for the flexible node allocation (default: "idle").'
+    )
+    run_options.add_argument(
+        '--force-local', action='store_true',
+        help='Force local execution of checks'
+    )
+    run_options.add_argument(
+        '-J', '--job-option', action='append', metavar='OPT',
+        dest='job_options', default=[],
+        help='Pass option OPT to job scheduler'
     )
     run_options.add_argument(
         '--max-retries', metavar='NUM', action='store', default=0,
@@ -352,19 +333,39 @@ def main():
         '--maxfail', metavar='NUM', action='store', default=sys.maxsize,
         help='Exit after first NUM failures'
     )
+    run_options.add_argument(
+        '--mode', action='store', help='Execution mode to use'
+    )
     run_options.add_argument(
         '--restore-session', action='store', nargs='?', const='',
         metavar='REPORT',
         help='Restore a testing session from REPORT file'
     )
     run_options.add_argument(
-        '--flex-alloc-nodes', action='store',
-        dest='flex_alloc_nodes', metavar='{all|STATE|NUM}', default=None,
-        help='Set strategy for the flexible node allocation (default: "idle").'
+        '-S', '--setvar', action='append', metavar='[TEST.]VAR=VAL',
+        dest='vars', default=[],
+        help=('Set test variable VAR to VAL in all tests '
+              'or optionally in TEST only')
     )
     run_options.add_argument(
-        '--disable-hook', action='append', metavar='NAME', dest='hooks',
-        default=[], help='Disable a pipeline hook for this run'
+        '--skip-performance-check', action='store_true',
+        help='Skip performance checking'
+    )
+    run_options.add_argument(
+        '--skip-prgenv-check', action='store_true',
+        help='Skip programming environment check'
+    )
+    run_options.add_argument(
+        '--skip-sanity-check', action='store_true',
+        help='Skip sanity checking'
+    )
+    run_options.add_argument(
+        '--skip-system-check', action='store_true',
+        help='Skip system check'
+    )
+    run_options.add_argument(
+        '--strict', action='store_true',
+        help='Enforce strict performance checking'
     )
 
     # Environment options
@@ -386,26 +387,26 @@ def main():
         help='Load module mappings from FILE',
         envvar='RFM_MODULE_MAP_FILE', configvar='general/module_map_file'
     )
-    env_options.add_argument(
-        '-u', '--unload-module', action='append', metavar='MOD',
-        dest='unload_modules', default=[],
-        help='Unload module MOD before running any regression check',
-        envvar='RFM_UNLOAD_MODULES ,', configvar='general/unload_modules'
-    )
     env_options.add_argument(
         '--module-path', action='append', metavar='PATH',
         dest='module_paths', default=[],
         help='(Un)use module path PATH before running any regression check',
     )
+    env_options.add_argument(
+        '--non-default-craype', action='store_true',
+        help='Test a non-default Cray Programming Environment',
+        envvar='RFM_NON_DEFAULT_CRAYPE', configvar='general/non_default_craype'
+    )
     env_options.add_argument(
         '--purge-env', action='store_true', dest='purge_env', default=False,
         help='Unload all modules before running any regression check',
         envvar='RFM_PURGE_ENVIRONMENT', configvar='general/purge_environment'
     )
     env_options.add_argument(
-        '--non-default-craype', action='store_true',
-        help='Test a non-default Cray Programming Environment',
-        envvar='RFM_NON_DEFAULT_CRAYPE', configvar='general/non_default_craype'
+        '-u', '--unload-module', action='append', metavar='MOD',
+        dest='unload_modules', default=[],
+        help='Unload module MOD before running any regression check',
+        envvar='RFM_UNLOAD_MODULES ,', configvar='general/unload_modules'
     )
 
     # Miscellaneous options
@@ -416,13 +417,17 @@ def main():
         envvar='RFM_CONFIG_FILE'
     )
     misc_options.add_argument(
-        '--nocolor', action='store_false', dest='colorize',
-        help='Disable coloring of output',
-        envvar='RFM_COLORIZE', configvar='general/colorize'
+        '--detect-host-topology', action='store', nargs='?', const='-',
+        help='Detect the local host topology and exit'
     )
     misc_options.add_argument(
         '--failure-stats', action='store_true', help='Print failure statistics'
     )
+    misc_options.add_argument(
+        '--nocolor', action='store_false', dest='colorize',
+        help='Disable coloring of output',
+        envvar='RFM_COLORIZE', configvar='general/colorize'
+    )
     misc_options.add_argument(
         '--performance-report', action='store_true',
         help='Print a report for performance tests'
@@ -436,10 +441,6 @@ def main():
         '--system', action='store', help='Load configuration for SYSTEM',
         envvar='RFM_SYSTEM'
     )
-    misc_options.add_argument(
-        '--detect-host-topology', action='store', nargs='?', const='-',
-        help='Detect the local host topology and exit'
-    )
     misc_options.add_argument(
         '--upgrade-config-file', action='store', metavar='OLD[:NEW]',
         help='Upgrade ReFrame 2.x configuration file to ReFrame 3.x syntax'
@@ -461,10 +462,10 @@ def main():
         help='Graylog server address'
     )
     argparser.add_argument(
-        dest='syslog_address',
-        envvar='RFM_SYSLOG_ADDRESS',
-        configvar='logging/handlers_perflog/syslog_address',
-        help='Syslog server address'
+        dest='httpjson_url',
+        envvar='RFM_HTTPJSON_URL',
+        configvar='logging/handlers_perflog/httpjson_url',
+        help='URL of HTTP server accepting JSON logs'
     )
     argparser.add_argument(
         dest='ignore_reqnodenotavail',
@@ -473,26 +474,6 @@ def main():
         action='store_true',
         help='Graylog server address'
     )
-    argparser.add_argument(
-        dest='use_login_shell',
-        envvar='RFM_USE_LOGIN_SHELL',
-        configvar='general/use_login_shell',
-        action='store_true',
-        help='Use a login shell for job scripts'
-    )
-    argparser.add_argument(
-        dest='resolve_module_conflicts',
-        envvar='RFM_RESOLVE_MODULE_CONFLICTS',
-        configvar='general/resolve_module_conflicts',
-        action='store_true',
-        help='Resolve module conflicts automatically'
-    )
-    argparser.add_argument(
-        dest='httpjson_url',
-        envvar='RFM_HTTPJSON_URL',
-        configvar='logging/handlers_perflog/httpjson_url',
-        help='URL of HTTP server accepting JSON logs'
-    )
     argparser.add_argument(
         dest='remote_detect',
         envvar='RFM_REMOTE_DETECT',
@@ -507,6 +488,26 @@ def main():
         action='store',
         help='Working directory for launching ReFrame remotely'
     )
+    argparser.add_argument(
+        dest='resolve_module_conflicts',
+        envvar='RFM_RESOLVE_MODULE_CONFLICTS',
+        configvar='general/resolve_module_conflicts',
+        action='store_true',
+        help='Resolve module conflicts automatically'
+    )
+    argparser.add_argument(
+        dest='syslog_address',
+        envvar='RFM_SYSLOG_ADDRESS',
+        configvar='logging/handlers_perflog/syslog_address',
+        help='Syslog server address'
+    )
+    argparser.add_argument(
+        dest='use_login_shell',
+        envvar='RFM_USE_LOGIN_SHELL',
+        configvar='general/use_login_shell',
+        action='store_true',
+        help='Use a login shell for job scripts'
+    )
 
     # Parse command line
     options = argparser.parse_args()
